@@ -21,6 +21,7 @@
 #include "helper.h"
 #include "../mailclient_p.h"
 #include "../fetchjobcalendar.h"
+#include "../utils_p.h"
 
 #include <kcalcore/icalformat.h>
 #include <kcalcore/attendee.h>
@@ -45,6 +46,7 @@ Q_DECLARE_METATYPE(KCalCore::Attendee::PartStat)
 Q_DECLARE_METATYPE(QList<int>)
 
 static const char *s_ourEmail = "unittests@dev.nul"; // change also in kdepimlibs/akonadi/calendar/tests/unittestenv/kdehome/share/config
+static const char *s_outEmail2 = "identity2@kde.org";
 
 void ITIPHandlerTest::initTestCase()
 {
@@ -60,13 +62,13 @@ void ITIPHandlerTest::initTestCase()
     m_changer->setInvitationPolicy(IncidenceChanger::InvitationPolicySend); // don't show dialogs
 
     connect(m_changer, SIGNAL(createFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
-            SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
+            SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
 
     connect(m_changer, SIGNAL(deleteFinished(int,QVector<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)),
-            SLOT(onDeleteFinished(int,QVector<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)));
+            SLOT(onDeleteFinished(int,QVector<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)) );
 
     connect(m_changer,SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
-            SLOT(onModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
+            SLOT(onModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
 }
 
 void ITIPHandlerTest::testProcessITIPMessage_data()
@@ -480,7 +482,7 @@ void ITIPHandlerTest::testOutgoingInvitations()
 
     m_cancelExpected = userCancels;
 
-    switch (changeType) {
+    switch(changeType) {
     case IncidenceChanger::ChangeTypeCreate:
         m_changer->createIncidence(incidence, mCollection);
         waitForIt();
@@ -503,7 +505,7 @@ void ITIPHandlerTest::testOutgoingInvitations()
         waitForIt();
         QCOMPARE(MailClient::sUnitTestResults.count(), expectedEmailCount);
     }
-    break;
+        break;
     case IncidenceChanger::ChangeTypeDelete:
         // Create if first, so we have something to delete
         m_changer->setGroupwareCommunication(false);
@@ -524,10 +526,42 @@ void ITIPHandlerTest::testOutgoingInvitations()
 
 }
 
+void ITIPHandlerTest::testIdentity_data()
+{
+    QTest::addColumn<QString>("email");
+    QTest::addColumn<bool>("expectedResult");
+
+    const QString myEmail = QLatin1String(s_ourEmail);
+    QString myEmail2      = QString::fromLatin1("Some name <%1>").arg(myEmail);
+
+    const QString myAlias1    = QLatin1String("alias1@kde.org"); // hardcoded in emailidentities, do not change
+    const QString myIdentity2 = QLatin1String(s_outEmail2);
+
+
+    QTest::newRow("Me")           << myEmail     << true;
+    QTest::newRow("Also me")      << myEmail2    << true;
+    QTest::newRow("My identity2") << myIdentity2 << true;
+    QTest::newRow("Not me")       << QString::fromLatin1("laura.palmer@twinpeaks.com") << false;
+
+    QTest::newRow("My alias") << myAlias1 << true;
+
+}
+
+void ITIPHandlerTest::testIdentity()
+{
+    QFETCH(QString, email);
+    QFETCH(bool, expectedResult);
+
+    if (CalendarUtils::thatIsMe(email) != expectedResult) {
+        qDebug() << email;
+        QVERIFY(false);
+    }
+}
+
 void ITIPHandlerTest::cleanup()
 {
     Akonadi::Item::List items = calendarItems();
-    foreach(const Akonadi::Item &item, items) {
+    foreach (const Akonadi::Item &item, items) {
         ItemDeleteJob *job = new ItemDeleteJob(item);
         AKVERIFYEXEC(job);
     }
@@ -541,7 +575,7 @@ void ITIPHandlerTest::createITIPHandler()
     m_itipHandler = new Akonadi::ITIPHandler();
     m_itipHandler->setShowDialogsOnError(false);
     connect(m_itipHandler, SIGNAL(iTipMessageProcessed(Akonadi::ITIPHandler::Result,QString)),
-            SLOT(oniTipMessageProcessed(Akonadi::ITIPHandler::Result,QString)));
+            SLOT(oniTipMessageProcessed(Akonadi::ITIPHandler::Result,QString)) );
 }
 
 QString ITIPHandlerTest::icalData(const QString &data_filename)
@@ -574,7 +608,7 @@ Attendee::Ptr ITIPHandlerTest::ourAttendee(const KCalCore::Incidence::Ptr &incid
 {
     KCalCore::Attendee::List attendees = incidence->attendees();
     KCalCore::Attendee::Ptr me;
-    foreach(const KCalCore::Attendee::Ptr &attendee, attendees) {
+    foreach (const KCalCore::Attendee::Ptr &attendee, attendees) {
         if (attendee->email() == QLatin1String(s_ourEmail)) {
             me = attendee;
             break;
@@ -643,8 +677,10 @@ void ITIPHandlerTest::onModifyFinished(int changeId, const Item &item,
     if (m_pendingIncidenceChangerSignal == 0) {
         stopWaiting();
     }
+    kDebug() << "Got result " << resultCode << m_cancelExpected;
     QCOMPARE(resultCode, m_cancelExpected ? IncidenceChanger::ResultCodeUserCanceled
-             : IncidenceChanger::ResultCodeSuccess);
+                                          : IncidenceChanger::ResultCodeSuccess);
 }
 
+
 QTEST_AKONADIMAIN(ITIPHandlerTest, GUI)
