@@ -23,15 +23,15 @@
 
 #include "contactactionssettings.h"
 #include "qdialer.h"
+#include "qsflphonedialer.h"
 #include "qskypedialer.h"
+#include "qekigadialer.h"
 #ifdef Q_OS_WINCE
 #include "qwincedialer.h"
 #endif // Q_OS_WINCE
 
 #include <kabc/phonenumber.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <krun.h>
 
@@ -66,6 +66,12 @@ void DialPhoneNumberAction::dialNumber( const KABC::PhoneNumber &number )
     dialer = new QWinCEDialer( QLatin1String( "AkonadiContacts" ) );
   }
 #endif // Q_OS_WINCE
+  else if ( ContactActionsSettings::self()->dialPhoneNumberAction() == ContactActionsSettings::UseSflPhone) {
+    dialer = new QSflPhoneDialer( QLatin1String( "AkonadiContacts" ) );
+  }
+  else if ( ContactActionsSettings::self()->dialPhoneNumberAction() == ContactActionsSettings::UseEkiga) {
+    dialer = new QEkigaDialer( QLatin1String( "AkonadiContacts" ) );
+  }
   if ( dialer ) {
     if ( !dialer->dialNumber( strippedDialNumber( number.number().trimmed() ) ) ) {
       KMessageBox::sorry( 0, dialer->errorMessage() );
