@@ -175,7 +175,6 @@ void EntityTreeModelPrivate::serverStarted()
   endResetModel();
 }
 
-
 ItemFetchJob* EntityTreeModelPrivate::getItemFetchJob( const Collection &parent, const ItemFetchScope &scope ) const
 {
   Q_ASSERT( parent.isValid() );
@@ -888,7 +887,6 @@ void EntityTreeModelPrivate::monitoredCollectionUnsubscribed( const Akonadi::Col
   monitoredCollectionRemoved( col );
 }
 
-
 void EntityTreeModelPrivate::removeChildEntities( Collection::Id collectionId )
 {
   QList<Node*> childList = m_childEntities.value( collectionId );
@@ -1304,18 +1302,6 @@ void EntityTreeModelPrivate::fetchJobDone( KJob *job )
 
     m_populatedCols.insert( collectionId );
     emit q_ptr->collectionPopulated( collectionId );
-  } else {
-    if ( !m_showRootCollection &&
-        collectionId == m_rootCollection.id() ) {
-      return;
-    }
-    // If collections are not in the model, there will be no valid index for them.
-    if ( ( m_collectionFetchStrategy != EntityTreeModel::InvisibleCollectionFetch ) &&
-        ( m_collectionFetchStrategy != EntityTreeModel::FetchNoCollections ) ) {
-      const QModelIndex index = indexForCollection( Collection( collectionId ) );
-      Q_ASSERT( index.isValid() );
-      emit dataChanged( index, index );
-    }
   }
 
   if ( !m_showRootCollection &&
@@ -1325,6 +1311,13 @@ void EntityTreeModelPrivate::fetchJobDone( KJob *job )
 
   m_pendingCollectionRetrieveJobs.remove( collectionId );
 
+  // If collections are not in the model, there will be no valid index for them.
+  if ( ( m_collectionFetchStrategy != EntityTreeModel::InvisibleCollectionFetch ) &&
+       ( m_collectionFetchStrategy != EntityTreeModel::FetchNoCollections ) ) {
+    const QModelIndex index = indexForCollection( Collection( collectionId ) );
+    Q_ASSERT( index.isValid() );
+    emit dataChanged( index, index );
+  }
 }
 
 void EntityTreeModelPrivate::pasteJobDone( KJob *job )
@@ -1424,7 +1417,6 @@ void EntityTreeModelPrivate::startFirstListJob()
     m_collections.insert( m_rootCollection.id(), m_rootCollection );
   }
 
-
   const bool noMimetypes = m_mimeChecker.wantedMimeTypes().isEmpty();
   const bool noResources = m_monitor->resourcesMonitored().isEmpty();
   const bool generalPopulation = !noMimetypes || ( noMimetypes && noResources );
@@ -1638,7 +1630,7 @@ QList<Node*>::iterator EntityTreeModelPrivate::removeItems( QList<Node*>::iterat
 
   QList<Node *> &es = m_childEntities[ collection.id() ];
   //NOTE: .erase will invalidate all iterators besides "it"!
-  for(int i = 0; i < toDelete; ++i) {
+  for (int i = 0; i < toDelete; ++i) {
     Q_ASSERT(es.count(*it) == 1);
     // don't keep implicitly shared data alive
     Q_ASSERT(m_items.contains((*it)->id));
@@ -1899,6 +1891,11 @@ bool EntityTreeModelPrivate::canFetchMore( const QModelIndex & parent ) const
       return false;
     }
 
+    // If the collection is no longer monitored by the monitor we have to refetch
+    if ( !m_monitor->d_ptr->isMonitored( colId ) ) {
+      return true;
+    }
+
     // Collections which contain no items at all can't contain more
     if ( m_collectionsWithoutItems.contains( colId ) ) {
       return false;
