@@ -114,27 +114,27 @@ void GData::listRecentPosts( const QStringList &labels, int number,
 {
   kDebug();
   Q_D( GData );
-  QString urlString( "http://www.blogger.com/feeds/" + blogId() + "/posts/default" );
+  QString urlString( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/posts/default") );
   if ( ! labels.empty() ) {
-    urlString += "/-/" + labels.join( "/" );
+    urlString += QLatin1String("/-/") + labels.join( QLatin1String("/") );
   }
   kDebug() << "listRecentPosts()";
   KUrl url( urlString );
 
   if ( !upMinTime.isNull() ) {
-    url.addQueryItem( "updated-min", upMinTime.toString() );
+    url.addQueryItem( QLatin1String("updated-min"), upMinTime.toString() );
   }
 
   if ( !upMaxTime.isNull() ) {
-    url.addQueryItem( "updated-max", upMaxTime.toString() );
+    url.addQueryItem( QLatin1String("updated-max"), upMaxTime.toString() );
   }
 
   if ( !pubMinTime.isNull() ) {
-    url.addQueryItem( "published-min", pubMinTime.toString() );
+    url.addQueryItem( QLatin1String("published-min"), pubMinTime.toString() );
   }
 
   if ( !pubMaxTime.isNull() ) {
-    url.addQueryItem( "published-max", pubMaxTime.toString() );
+    url.addQueryItem( QLatin1String("published-max"), pubMaxTime.toString() );
   }
 
   Syndication::Loader *loader = Syndication::Loader::create();
@@ -164,8 +164,8 @@ void GData::listComments( KBlog::BlogPost *post )
            SIGNAL(loadingComplete(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)),
            this,
            SLOT(slotListComments(Syndication::Loader*,Syndication::FeedPtr,Syndication::ErrorCode)) );
-  loader->loadFrom( QString("http://www.blogger.com/feeds/" + blogId() + '/' +
-                    post->postId() + "/comments/default") );
+  loader->loadFrom( QString(QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1Char('/') +
+                    post->postId() + QLatin1String("/comments/default")) );
 }
 
 void GData::listAllComments()
@@ -215,50 +215,50 @@ void GData::modifyPost( KBlog::BlogPost *post )
     return;
   }
 
-  QString atomMarkup = "<entry xmlns='http://www.w3.org/2005/Atom'>";
-  atomMarkup += "<id>tag:blogger.com,1999:blog-" + blogId();
-  atomMarkup += ".post-" + post->postId() + "</id>";
-  atomMarkup += "<published>" + post->creationDateTime().toString() + "</published>";
-  atomMarkup += "<updated>" + post->modificationDateTime().toString() + "</updated>";
-  atomMarkup += "<title type='text'>" + post->title() + "</title>";
+  QString atomMarkup = QLatin1String("<entry xmlns='http://www.w3.org/2005/Atom'>");
+  atomMarkup += QLatin1String("<id>tag:blogger.com,1999:blog-") + blogId();
+  atomMarkup += QLatin1String(".post-") + post->postId() + QLatin1String("</id>");
+  atomMarkup += QLatin1String("<published>") + post->creationDateTime().toString() + QLatin1String("</published>");
+  atomMarkup += QLatin1String("<updated>") + post->modificationDateTime().toString() + QLatin1String("</updated>");
+  atomMarkup += QLatin1String("<title type='text'>") + post->title() + QLatin1String("</title>");
   if ( post->isPrivate() ) {
-    atomMarkup += "<app:control xmlns:app='http://purl.org/atom/app#'>";
-    atomMarkup += "<app:draft>yes</app:draft></app:control>";
+    atomMarkup += QLatin1String("<app:control xmlns:app='http://purl.org/atom/app#'>");
+    atomMarkup += QLatin1String("<app:draft>yes</app:draft></app:control>");
   }
-  atomMarkup += "<content type='xhtml'>";
-  atomMarkup += "<div xmlns='http://www.w3.org/1999/xhtml'>";
+  atomMarkup += QLatin1String("<content type='xhtml'>");
+  atomMarkup += QLatin1String("<div xmlns='http://www.w3.org/1999/xhtml'>");
   atomMarkup += post->content();
-  atomMarkup += "</div></content>";
+  atomMarkup += QLatin1String("</div></content>");
   QList<QString>::ConstIterator it = post->tags().constBegin();
   QList<QString>::ConstIterator end = post->tags().constEnd();
   for ( ; it != end; ++it ) {
-    atomMarkup += "<category scheme='http://www.blogger.com/atom/ns#' term='" + ( *it ) + "' />";
+    atomMarkup += QLatin1String("<category scheme='http://www.blogger.com/atom/ns#' term='") + ( *it ) + QLatin1String("' />");
   }
-  atomMarkup += "<author>";
+  atomMarkup += QLatin1String("<author>");
   if ( !fullName().isEmpty() ) {
-    atomMarkup += "<name>" + fullName() + "</name>";
+    atomMarkup += QLatin1String("<name>") + fullName() + QLatin1String("</name>");
   }
-  atomMarkup += "<email>" + username() + "</email>";
-  atomMarkup += "</author>";
-  atomMarkup += "</entry>";
+  atomMarkup += QLatin1String("<email>") + username() + QLatin1String("</email>");
+  atomMarkup += QLatin1String("</author>");
+  atomMarkup += QLatin1String("</entry>");
   QByteArray postData;
   QDataStream stream( &postData, QIODevice::WriteOnly );
   stream.writeRawData( atomMarkup.toUtf8(), atomMarkup.toUtf8().length() );
 
   KIO::StoredTransferJob *job = KIO::storedHttpPost( postData,
-      KUrl( "http://www.blogger.com/feeds/" + blogId() + "/posts/default/" + post->postId() ),
+      KUrl( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/posts/default/") + post->postId() ),
       KIO::HideProgressInfo );
 
   Q_ASSERT( job );
 
   d->mModifyPostMap[ job ] = post;
 
-  job->addMetaData( "content-type", "Content-Type: application/atom+xml; charset=utf-8" );
-  job->addMetaData( "ConnectTimeout", "50" );
-  job->addMetaData( "UserAgent", userAgent() );
-  job->addMetaData( "customHTTPHeader",
-                    "Authorization: GoogleLogin auth=" + d->mAuthenticationString +
-                    "\r\nX-HTTP-Method-Override: PUT" );
+  job->addMetaData( QLatin1String("content-type"), QLatin1String("Content-Type: application/atom+xml; charset=utf-8") );
+  job->addMetaData( QLatin1String("ConnectTimeout"), QLatin1String("50") );
+  job->addMetaData( QLatin1String("UserAgent"), userAgent() );
+  job->addMetaData( QLatin1String("customHTTPHeader"),
+                    QLatin1String("Authorization: GoogleLogin auth=") + d->mAuthenticationString +
+                    QLatin1String("\r\nX-HTTP-Method-Override: PUT") );
 
   connect( job, SIGNAL(result(KJob*)),
            this, SLOT(slotModifyPost(KJob*)) );
@@ -280,45 +280,45 @@ void GData::createPost( KBlog::BlogPost *post )
     return;
   }
 
-  QString atomMarkup = "<entry xmlns='http://www.w3.org/2005/Atom'>";
-  atomMarkup += "<title type='text'>" + post->title() + "</title>";
+  QString atomMarkup = QLatin1String("<entry xmlns='http://www.w3.org/2005/Atom'>");
+  atomMarkup += QLatin1String("<title type='text'>") + post->title() + QLatin1String("</title>");
   if ( post->isPrivate() ) {
-    atomMarkup += "<app:control xmlns:app='http://purl.org/atom/app#'>";
-    atomMarkup += "<app:draft>yes</app:draft></app:control>";
+    atomMarkup += QLatin1String("<app:control xmlns:app='http://purl.org/atom/app#'>");
+    atomMarkup += QLatin1String("<app:draft>yes</app:draft></app:control>");
   }
-  atomMarkup += "<content type='xhtml'>";
-  atomMarkup += "<div xmlns='http://www.w3.org/1999/xhtml'>";
+  atomMarkup += QLatin1String("<content type='xhtml'>");
+  atomMarkup += QLatin1String("<div xmlns='http://www.w3.org/1999/xhtml'>");
   atomMarkup += post->content(); // FIXME check for Utf
-  atomMarkup += "</div></content>";
+  atomMarkup += QLatin1String("</div></content>");
   QList<QString>::ConstIterator it = post->tags().constBegin();
   QList<QString>::ConstIterator end = post->tags().constEnd();
   for ( ; it != end; ++it ) {
-    atomMarkup += "<category scheme='http://www.blogger.com/atom/ns#' term='" + ( *it ) + "' />";
+    atomMarkup += QLatin1String("<category scheme='http://www.blogger.com/atom/ns#' term='") + ( *it ) + QLatin1String("' />");
   }
-  atomMarkup += "<author>";
+  atomMarkup += QLatin1String("<author>");
   if ( !fullName().isEmpty() ) {
-    atomMarkup += "<name>" + fullName() + "</name>";
+    atomMarkup += QLatin1String("<name>") + fullName() + QLatin1String("</name>");
   }
-  atomMarkup += "<email>" + username() + "</email>";
-  atomMarkup += "</author>";
-  atomMarkup += "</entry>";
+  atomMarkup += QLatin1String("<email>") + username() + QLatin1String("</email>");
+  atomMarkup += QLatin1String("</author>");
+  atomMarkup += QLatin1String("</entry>");
 
   QByteArray postData;
   QDataStream stream( &postData, QIODevice::WriteOnly );
   stream.writeRawData( atomMarkup.toUtf8(), atomMarkup.toUtf8().length() );
 
   KIO::StoredTransferJob *job = KIO::storedHttpPost( postData,
-    KUrl( "http://www.blogger.com/feeds/" + blogId() + "/posts/default" ),
+    KUrl( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/posts/default") ),
     KIO::HideProgressInfo );
 
   Q_ASSERT ( job );
   d->mCreatePostMap[ job ] = post;
 
-  job->addMetaData( "content-type", "Content-Type: application/atom+xml; charset=utf-8" );
-  job->addMetaData( "ConnectTimeout", "50" );
-  job->addMetaData( "UserAgent", userAgent() );
-  job->addMetaData( "customHTTPHeader",
-                    "Authorization: GoogleLogin auth=" + d->mAuthenticationString );
+  job->addMetaData( QLatin1String("content-type"), QLatin1String("Content-Type: application/atom+xml; charset=utf-8") );
+  job->addMetaData( QLatin1String("ConnectTimeout"), QLatin1String("50") );
+  job->addMetaData( QLatin1String("UserAgent"), userAgent() );
+  job->addMetaData( QLatin1String("customHTTPHeader"),
+                    QLatin1String("Authorization: GoogleLogin auth=") + d->mAuthenticationString );
 
   connect( job, SIGNAL(result(KJob*)),
            this, SLOT(slotCreatePost(KJob*)) );
@@ -343,21 +343,21 @@ void GData::removePost( KBlog::BlogPost *post )
   QByteArray postData;
 
   KIO::StoredTransferJob *job = KIO::storedHttpPost( postData,
-    KUrl( "http://www.blogger.com/feeds/" + blogId() + "/posts/default/" + post->postId() ),
+    KUrl( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/posts/default/") + post->postId() ),
     KIO::HideProgressInfo );
 
   d->mRemovePostMap[ job ] = post;
 
   if ( !job ) {
     kWarning() << "Unable to create KIO job for http://www.blogger.com/feeds/"
-               << blogId() << "/posts/default/" + post->postId();
+               << blogId() << QLatin1String("/posts/default/") + post->postId();
   }
 
-  job->addMetaData( "ConnectTimeout", "50" );
-  job->addMetaData( "UserAgent", userAgent() );
-  job->addMetaData( "customHTTPHeader",
-                    "Authorization: GoogleLogin auth=" + d->mAuthenticationString +
-                    "\r\nX-HTTP-Method-Override: DELETE" );
+  job->addMetaData( QLatin1String("ConnectTimeout"), QLatin1String("50") );
+  job->addMetaData( QLatin1String("UserAgent"), userAgent() );
+  job->addMetaData( QLatin1String("customHTTPHeader"),
+                    QLatin1String("Authorization: GoogleLogin auth=") + d->mAuthenticationString +
+                    QLatin1String("\r\nX-HTTP-Method-Override: DELETE") );
 
   connect( job, SIGNAL(result(KJob*)),
            this, SLOT(slotRemovePost(KJob*)) );
@@ -383,13 +383,13 @@ void GData::createComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
     emit errorComment( Atom, i18n( "Authentication failed." ), post, comment );
     return;
   }
-  QString atomMarkup = "<entry xmlns='http://www.w3.org/2005/Atom'>";
-  atomMarkup += "<title type=\"text\">" + comment->title() + "</title>";
-  atomMarkup += "<content type=\"html\">" + comment->content() + "</content>";
-  atomMarkup += "<author>";
-  atomMarkup += "<name>" + comment->name() + "</name>";
-  atomMarkup += "<email>" + comment->email() + "</email>";
-  atomMarkup += "</author></entry>";
+  QString atomMarkup = QLatin1String("<entry xmlns='http://www.w3.org/2005/Atom'>");
+  atomMarkup += QLatin1String("<title type=\"text\">") + comment->title() + QLatin1String("</title>");
+  atomMarkup += QLatin1String("<content type=\"html\">") + comment->content() + QLatin1String("</content>");
+  atomMarkup += QLatin1String("<author>");
+  atomMarkup += QLatin1String("<name>") + comment->name() + QLatin1String("</name>");
+  atomMarkup += QLatin1String("<email>") + comment->email() + QLatin1String("</email>");
+  atomMarkup += QLatin1String("</author></entry>");
 
   QByteArray postData;
   kDebug() <<  postData;
@@ -397,7 +397,7 @@ void GData::createComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
   stream.writeRawData( atomMarkup.toUtf8(), atomMarkup.toUtf8().length() );
 
   KIO::StoredTransferJob *job = KIO::storedHttpPost( postData,
-    KUrl( "http://www.blogger.com/feeds/" + blogId() + "/" + post->postId() + "/comments/default" ),
+    KUrl( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/") + post->postId() + QLatin1String("/comments/default") ),
     KIO::HideProgressInfo );
 
   d->mCreateCommentMap[ job ][post] = comment;
@@ -407,11 +407,11 @@ void GData::createComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
                << blogId() << "/" << post->postId() << "/comments/default";
   }
 
-  job->addMetaData( "content-type", "Content-Type: application/atom+xml; charset=utf-8" );
-  job->addMetaData( "ConnectTimeout", "50" );
-  job->addMetaData( "customHTTPHeader",
-                    "Authorization: GoogleLogin auth=" + d->mAuthenticationString );
-  job->addMetaData( "UserAgent", userAgent() );
+  job->addMetaData( QLatin1String("content-type"), QLatin1String("Content-Type: application/atom+xml; charset=utf-8") );
+  job->addMetaData( QLatin1String("ConnectTimeout"), QLatin1String("50") );
+  job->addMetaData( QLatin1String("customHTTPHeader"),
+                    QLatin1String("Authorization: GoogleLogin auth=") + d->mAuthenticationString );
+  job->addMetaData( QLatin1String("UserAgent"), userAgent() );
 
   connect( job, SIGNAL(result(KJob*)),
            this, SLOT(slotCreateComment(KJob*)) );
@@ -442,8 +442,8 @@ void GData::removeComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
   QByteArray postData;
 
   KIO::StoredTransferJob *job = KIO::storedHttpPost(postData,
-    KUrl( "http://www.blogger.com/feeds/" + blogId() + "/" + post->postId() +
-          "/comments/default/" + comment->commentId() ), KIO::HideProgressInfo );
+    KUrl( QLatin1String("http://www.blogger.com/feeds/") + blogId() + QLatin1String("/") + post->postId() +
+          QLatin1String("/comments/default/") + comment->commentId() ), KIO::HideProgressInfo );
   d->mRemoveCommentMap[ job ][ post ] = comment;
 
   if ( !job ) {
@@ -452,11 +452,11 @@ void GData::removeComment( KBlog::BlogPost *post, KBlog::BlogComment *comment )
                << "/comments/default/" << comment->commentId();
   }
 
-  job->addMetaData( "ConnectTimeout", "50" );
-  job->addMetaData( "UserAgent", userAgent() );
-  job->addMetaData( "customHTTPHeader",
-                    "Authorization: GoogleLogin auth=" +
-                    d->mAuthenticationString + "\r\nX-HTTP-Method-Override: DELETE" );
+  job->addMetaData( QLatin1String("ConnectTimeout"), QLatin1String("50") );
+  job->addMetaData( QLatin1String("UserAgent"), userAgent() );
+  job->addMetaData( QLatin1String("customHTTPHeader"),
+                    QLatin1String("Authorization: GoogleLogin auth=") +
+                    d->mAuthenticationString + QLatin1String("\r\nX-HTTP-Method-Override: DELETE") );
 
   connect( job, SIGNAL(result(KJob*)),
            this, SLOT(slotRemoveComment(KJob*)) );
@@ -477,18 +477,18 @@ bool GDataPrivate::authenticate()
   kDebug();
   Q_Q( GData );
   QByteArray data;
-  KUrl authGateway( "https://www.google.com/accounts/ClientLogin" );
-  authGateway.addQueryItem( "Email", q->username() );
-  authGateway.addQueryItem( "Passwd", q->password() );
-  authGateway.addQueryItem( "source", q->userAgent() );
-  authGateway.addQueryItem( "service", "blogger" );
+  KUrl authGateway( QLatin1String("https://www.google.com/accounts/ClientLogin") );
+  authGateway.addQueryItem( QLatin1String("Email"), q->username() );
+  authGateway.addQueryItem( QLatin1String("Passwd"), q->password() );
+  authGateway.addQueryItem( QLatin1String("source"), q->userAgent() );
+  authGateway.addQueryItem( QLatin1String("service"), QLatin1String("blogger") );
   if ( !mAuthenticationTime.isValid() ||
        QDateTime::currentDateTime().toTime_t() - mAuthenticationTime.toTime_t() > TIMEOUT ||
        mAuthenticationString.isEmpty() ) {
     KIO::Job *job = KIO::http_post( authGateway, QByteArray(), KIO::HideProgressInfo );
     if ( KIO::NetAccess::synchronousRun( job, (QWidget*)0, &data, &authGateway ) ) {
-      QRegExp rx( "Auth=(.+)" );
-      if ( rx.indexIn( data ) != -1 ) {
+      QRegExp rx( QLatin1String("Auth=(.+)") );
+      if ( rx.indexIn( QLatin1String(data) ) != -1 ) {
         kDebug() << "RegExp got authentication string:" << rx.cap( 1 );
         mAuthenticationString = rx.cap( 1 );
         mAuthenticationTime = QDateTime::currentDateTime();
@@ -511,7 +511,7 @@ void GDataPrivate::slotFetchProfileId( KJob *job )
   KIO::StoredTransferJob *stj = qobject_cast<KIO::StoredTransferJob*>( job );
   const QString data = QString::fromUtf8( stj->data(), stj->data().size() );
   if ( !job->error() ) {
-    QRegExp pid( "http://www.blogger.com/profile/(\\d+)" );
+    QRegExp pid( QLatin1String("http://www.blogger.com/profile/(\\d+)") );
     if ( pid.indexIn( data ) != -1 ) {
       q->setProfileId( pid.cap( 1 ) );
       kDebug() << "QRegExp bid( 'http://www.blogger.com/profile/(\\d+)' matches" << pid.cap( 1 );
@@ -549,14 +549,14 @@ void GDataPrivate::slotListBlogs( Syndication::Loader *loader,
   QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
-    QRegExp rx( "blog-(\\d+)" );
+    QRegExp rx( QLatin1String("blog-(\\d+)") );
     QMap<QString,QString> blogInfo;
     if ( rx.indexIn( ( *it )->id() ) != -1 ) {
       kDebug() << "QRegExp rx( 'blog-(\\d+)' matches" << rx.cap( 1 );
-      blogInfo["id"] = rx.cap( 1 );
-      blogInfo["title"] = ( *it )->title();
-      blogInfo["url"] = ( *it )->link();
-      blogInfo["summary"] = ( *it )->description(); //TODO fix/add more
+      blogInfo[QLatin1String("id")] = rx.cap( 1 );
+      blogInfo[QLatin1String("title")] = ( *it )->title();
+      blogInfo[QLatin1String("url")] = ( *it )->link();
+      blogInfo[QLatin1String("summary")] = ( *it )->description(); //TODO fix/add more
       blogsList << blogInfo;
     } else {
       kError() << "QRegExp rx( 'blog-(\\d+)' does not match anything in:"
@@ -593,7 +593,7 @@ void GDataPrivate::slotListComments( Syndication::Loader *loader,
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogComment comment;
-    QRegExp rx( "post-(\\d+)" );
+    QRegExp rx( QLatin1String("post-(\\d+)") );
     if ( rx.indexIn( ( *it )->id() ) == -1 ) {
       kError() << "QRegExp rx( 'post-(\\d+)' does not match" << rx.cap( 1 );
       emit q->error( GData::Other, i18n( "Could not regexp the comment id path." ) );
@@ -639,7 +639,7 @@ void GDataPrivate::slotListAllComments( Syndication::Loader *loader,
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogComment comment;
-    QRegExp rx( "post-(\\d+)" );
+    QRegExp rx( QLatin1String("post-(\\d+)") );
     if ( rx.indexIn( ( *it )->id() ) == -1 ) {
       kError() << "QRegExp rx( 'post-(\\d+)' does not match" << rx.cap( 1 );
       emit q->error( GData::Other, i18n( "Could not regexp the comment id path." ) );
@@ -691,7 +691,7 @@ void GDataPrivate::slotListRecentPosts( Syndication::Loader *loader,
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogPost post;
-    QRegExp rx( "post-(\\d+)" );
+    QRegExp rx( QLatin1String("post-(\\d+)") );
     if ( rx.indexIn( ( *it )->id() ) == -1 ) {
       kError() << "QRegExp rx( 'post-(\\d+)' does not match" << rx.cap( 1 );
       emit q->error( GData::Other, i18n( "Could not regexp the post id path." ) );
@@ -758,7 +758,7 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
   QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
   QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
-    QRegExp rx( "post-(\\d+)" );
+    QRegExp rx( QLatin1String("post-(\\d+)") );
     if ( rx.indexIn( ( *it )->id() ) != -1 &&
          rx.cap( 1 ) == postId ) {
       kDebug() << "QRegExp rx( 'post-(\\d+)' matches" << rx.cap( 1 );
@@ -807,7 +807,7 @@ void GDataPrivate::slotCreatePost( KJob *job )
     return;
   }
 
-  QRegExp rxId( "post-(\\d+)" ); //FIXME check and do better handling, esp the creation date time
+  QRegExp rxId( QLatin1String("post-(\\d+)") ); //FIXME check and do better handling, esp the creation date time
   if ( rxId.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the id out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -816,7 +816,7 @@ void GDataPrivate::slotCreatePost( KJob *job )
   }
   kDebug() << "QRegExp rx( 'post-(\\d+)' ) matches" << rxId.cap( 1 );
 
-  QRegExp rxPub( "<published>(.+)</published>" );
+  QRegExp rxPub( QLatin1String("<published>(.+)</published>") );
   if ( rxPub.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the published time out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -825,7 +825,7 @@ void GDataPrivate::slotCreatePost( KJob *job )
   }
   kDebug() << "QRegExp rx( '<published>(.+)</published>' ) matches" << rxPub.cap( 1 );
 
-  QRegExp rxUp( "<updated>(.+)</updated>" );
+  QRegExp rxUp( QLatin1String("<updated>(.+)</updated>") );
   if ( rxUp.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the update time out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -861,7 +861,7 @@ void GDataPrivate::slotModifyPost( KJob *job )
     return;
   }
 
-  QRegExp rxId( "post-(\\d+)" ); //FIXME check and do better handling, esp creation date time
+  QRegExp rxId( QLatin1String("post-(\\d+)") ); //FIXME check and do better handling, esp creation date time
   if ( rxId.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the id out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -870,7 +870,7 @@ void GDataPrivate::slotModifyPost( KJob *job )
   }
   kDebug() << "QRegExp rx( 'post-(\\d+)' ) matches" << rxId.cap( 1 );
 
-  QRegExp rxPub( "<published>(.+)</published>" );
+  QRegExp rxPub( QLatin1String("<published>(.+)</published>") );
   if ( rxPub.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the published time out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -879,7 +879,7 @@ void GDataPrivate::slotModifyPost( KJob *job )
   }
   kDebug() << "QRegExp rx( '<published>(.+)</published>' ) matches" << rxPub.cap( 1 );
 
-  QRegExp rxUp( "<updated>(.+)</updated>" );
+  QRegExp rxUp( QLatin1String("<updated>(.+)</updated>") );
   if ( rxUp.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the update time out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -942,7 +942,7 @@ void GDataPrivate::slotCreateComment( KJob *job )
   }
 
 // TODO check for result and fit appropriately
-  QRegExp rxId( "post-(\\d+)" );
+  QRegExp rxId( QLatin1String("post-(\\d+)") );
   if ( rxId.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the id out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -951,7 +951,7 @@ void GDataPrivate::slotCreateComment( KJob *job )
   }
   kDebug() << "QRegExp rx( 'post-(\\d+)' ) matches" << rxId.cap( 1 );
 
-  QRegExp rxPub( "<published>(.+)</published>" );
+  QRegExp rxPub( QLatin1String("<published>(.+)</published>") );
   if ( rxPub.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the published time out of the result:" << data;
     emit q->errorPost( GData::Atom,
@@ -960,7 +960,7 @@ void GDataPrivate::slotCreateComment( KJob *job )
   }
   kDebug() << "QRegExp rx( '<published>(.+)</published>' ) matches" << rxPub.cap( 1 );
 
-  QRegExp rxUp( "<updated>(.+)</updated>" );
+  QRegExp rxUp( QLatin1String("<updated>(.+)</updated>") );
   if ( rxUp.indexIn( data ) == -1 ) {
     kError() << "Could not regexp the update time out of the result:" << data;
     emit q->errorPost( GData::Atom,
