@@ -42,59 +42,60 @@ typedef SortableList<QTime> TimeList;
 */
 class KCALCORE_EXPORT RecurrenceRule
 {
-public:
+  public:
     class RuleObserver
     {
-    public:
+      public:
         virtual ~RuleObserver();
         /** This method is called on each change of the recurrence object */
-        virtual void recurrenceChanged(RecurrenceRule *) = 0;
+        virtual void recurrenceChanged( RecurrenceRule * ) = 0;
     };
     typedef QList<RecurrenceRule*> List;
 
     /** enum for describing the frequency how an event recurs, if at all. */
     enum PeriodType {
-        rNone = 0,
-        rSecondly,
-        rMinutely,
-        rHourly,
-        rDaily,
-        rWeekly,
-        rMonthly,
-        rYearly
+      rNone = 0,
+      rSecondly,
+      rMinutely,
+      rHourly,
+      rDaily,
+      rWeekly,
+      rMonthly,
+      rYearly
     };
 
     /** structure for describing the n-th weekday of the month/year. */
     class KCALCORE_EXPORT WDayPos //krazy:exclude=dpointer
     {
-    public:
-        explicit WDayPos(int ps = 0, short dy = 0);
-        void setDay(short dy);
+      public:
+        explicit WDayPos( int ps = 0, short dy = 0 );
+        void setDay( short dy );
         short day() const;
-        void setPos(int ps);
+        void setPos( int ps );
         int pos() const;
 
-        bool operator==(const RecurrenceRule::WDayPos &pos2) const;
-        bool operator!=(const RecurrenceRule::WDayPos &pos2) const;
+        bool operator==( const RecurrenceRule::WDayPos &pos2 ) const;
+        bool operator!=( const RecurrenceRule::WDayPos &pos2 ) const;
 
-    protected:
+      protected:
         short mDay; // Weekday, 1=monday, 7=sunday
         int mPos;   // week of the day (-1 for last, 1 for first, 0 for all weeks)
-        // Bounded by -366 and +366, 0 means all weeks in that period
+                    // Bounded by -366 and +366, 0 means all weeks in that period
+
+        friend KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, const KCalCore::RecurrenceRule::WDayPos & );
+        friend KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, KCalCore::RecurrenceRule::WDayPos & );
     };
 
     RecurrenceRule();
-    RecurrenceRule(const RecurrenceRule &r);
+    RecurrenceRule( const RecurrenceRule &r );
     ~RecurrenceRule();
 
-    bool operator==(const RecurrenceRule &r) const;
-    bool operator!=(const RecurrenceRule &r) const  {
-        return !operator==(r);
-    }
-    RecurrenceRule &operator=(const RecurrenceRule &r);
+    bool operator==( const RecurrenceRule &r ) const;
+    bool operator!=( const RecurrenceRule &r ) const  { return !operator==(r); }
+    RecurrenceRule &operator=( const RecurrenceRule &r );
 
     /** Set if recurrence is read-only or can be changed. */
-    void setReadOnly(bool readOnly);
+    void setReadOnly( bool readOnly );
 
     /**
       Returns true if the recurrence is read-only; false if it can be changed.
@@ -106,7 +107,7 @@ public:
       of this file for possible values.
     */
     bool recurs() const;
-    void setRecurrenceType(PeriodType period);
+    void setRecurrenceType( PeriodType period );
     PeriodType recurrenceType() const;
 
     /** Turns off recurrence for the event. */
@@ -120,7 +121,7 @@ public:
     /**
       Sets the recurrence frequency, in terms of the recurrence time period type.
     */
-    void setFrequency(int freq);
+    void setFrequency( int freq );
 
     /**
       Returns the recurrence start date/time.
@@ -141,7 +142,7 @@ public:
 
       @param start the recurrence's start date and time
     */
-    void setStartDt(const KDateTime &start);
+    void setStartDt( const KDateTime &start );
 
     /** Returns whether the start date has no time associated. All-Day
         means -- according to rfc2445 -- that the event has no time associate. */
@@ -151,18 +152,18 @@ public:
      *
      * @param allDay Whether start datetime is all-day
      */
-    void setAllDay(bool allDay);
+    void setAllDay( bool allDay );
 
     /** Returns the date and time of the last recurrence.
      * An invalid date is returned if the recurrence has no end.
      * @param result if non-null, *result is updated to true if successful,
      * or false if there is no recurrence or its end date cannot be determined.
      */
-    KDateTime endDt(bool *result = 0) const;
+    KDateTime endDt( bool *result = 0 ) const;
 
     /** Sets the date and time of the last recurrence.
      * @param endDateTime the ending date/time after which to stop recurring. */
-    void setEndDt(const KDateTime &endDateTime);
+    void setEndDt( const KDateTime &endDateTime );
 
     /**
      * Returns -1 if the event recurs infinitely, 0 if the end date is set,
@@ -172,13 +173,13 @@ public:
 
     /** Sets the total number of times the event is to occur, including both the
      * first and last. */
-    void setDuration(int duration);
+    void setDuration( int duration );
 
     /** Returns the number of recurrences up to and including the date/time specified. */
-    int durationTo(const KDateTime &dt) const;
+    int durationTo( const KDateTime &dt ) const;
 
     /** Returns the number of recurrences up to and including the date specified. */
-    int durationTo(const QDate &date) const;
+    int durationTo( const QDate &date ) const;
 
     /**
       Shift the times of the rule so that they appear at the same clock
@@ -194,7 +195,7 @@ public:
       @param oldSpec the time specification which provides the clock times
       @param newSpec the new time specification
     */
-    void shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec);
+    void shiftTimes( const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec );
 
     /** Returns true if the date specified is one on which the event will
      * recur. The start date returns true only if it actually matches the rule.
@@ -202,7 +203,7 @@ public:
      * @param date date to check
      * @param timeSpec time specification for @p date
      */
-    bool recursOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
+    bool recursOn( const QDate &date, const KDateTime::Spec &timeSpec ) const;
 
     /** Returns true if the date/time specified is one at which the event will
      * recur. Times are rounded down to the nearest minute to determine the result.
@@ -210,7 +211,7 @@ public:
      *
      * @param dt the date+time to check for recurrency
      */
-    bool recursAt(const KDateTime &dt) const;
+    bool recursAt( const KDateTime &dt ) const;
 
     /** Returns true if the date matches the rules. It does not necessarily
         mean that this is an actual occurrence. In particular, the method does
@@ -219,7 +220,7 @@ public:
 
         @param dt the date+time to check for matching the rules
      */
-    bool dateMatchesRules(const KDateTime &dt) const;
+    bool dateMatchesRules( const KDateTime &dt ) const;
 
     /** Returns a list of the times on the specified date at which the
      * recurrence will occur. The returned times should be interpreted in the
@@ -227,7 +228,7 @@ public:
      * @param date the date for which to find the recurrence times
      * @param timeSpec time specification for @p date
      */
-    TimeList recurTimesOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
+    TimeList recurTimesOn( const QDate &date, const KDateTime::Spec &timeSpec ) const;
 
     /** Returns a list of all the times at which the recurrence will occur
      * between two specified times.
@@ -240,14 +241,14 @@ public:
      * @param end inclusive end of interval
      * @return list of date/time values
      */
-    DateTimeList timesInInterval(const KDateTime &start, const KDateTime &end) const;
+    DateTimeList timesInInterval( const KDateTime &start, const KDateTime &end ) const;
 
     /** Returns the date and time of the next recurrence, after the specified date/time.
      * If the recurrence has no time, the next date after the specified date is returned.
      * @param preDateTime the date/time after which to find the recurrence.
      * @return date/time of next recurrence, or invalid date if none.
      */
-    KDateTime getNextDate(const KDateTime &preDateTime) const;
+    KDateTime getNextDate( const KDateTime &preDateTime ) const;
 
     /** Returns the date and time of the last previous recurrence, before the specified date/time.
      * If a time later than 00:00:00 is specified and the recurrence has no time, 00:00:00 on
@@ -255,19 +256,19 @@ public:
      * @param afterDateTime the date/time before which to find the recurrence.
      * @return date/time of previous recurrence, or invalid date if none.
      */
-    KDateTime getPreviousDate(const KDateTime &afterDateTime) const;
+    KDateTime getPreviousDate( const KDateTime &afterDateTime ) const;
 
-    void setBySeconds(const QList<int> &bySeconds);
-    void setByMinutes(const QList<int> &byMinutes);
-    void setByHours(const QList<int> &byHours);
+    void setBySeconds( const QList<int> &bySeconds );
+    void setByMinutes( const QList<int> &byMinutes );
+    void setByHours( const QList<int> &byHours );
 
-    void setByDays(const QList<WDayPos> &byDays);
-    void setByMonthDays(const QList<int> &byMonthDays);
-    void setByYearDays(const QList<int> &byYearDays);
-    void setByWeekNumbers(const QList<int> &byWeekNumbers);
-    void setByMonths(const QList<int> &byMonths);
-    void setBySetPos(const QList<int> &bySetPos);
-    void setWeekStart(short weekStart);
+    void setByDays( const QList<WDayPos> &byDays );
+    void setByMonthDays( const QList<int> &byMonthDays );
+    void setByYearDays( const QList<int> &byYearDays );
+    void setByWeekNumbers( const QList<int> &byWeekNumbers );
+    void setByMonths( const QList<int> &byMonths );
+    void setBySetPos( const QList<int> &bySetPos );
+    void setWeekStart( short weekStart );
 
     const QList<int> &bySeconds() const;
     const QList<int> &byMinutes() const;
@@ -288,7 +289,7 @@ public:
 
       @param rrule the RRULE string
      */
-    void setRRule(const QString &rrule);
+    void setRRule( const QString &rrule );
     QString rrule() const;
 
     void setDirty();
@@ -299,7 +300,7 @@ public:
       @param observer the Recurrence::Observer-derived object, which
       will be installed as an observer of this object.
     */
-    void addObserver(RuleObserver *observer);
+    void addObserver( RuleObserver *observer );
 
     /**
       Removes an observer that was added with addObserver. If the
@@ -307,20 +308,37 @@ public:
       @param observer the Recurrence::Observer-derived object to
       be removed from the list of observers of this object.
     */
-    void removeObserver(RuleObserver *observer);
+    void removeObserver( RuleObserver *observer );
 
     /**
       Debug output.
     */
     void dump() const;
 
-private:
+  private:
     //@cond PRIVATE
     class Private;
     Private *const d;
     //@endcond
+
+    friend KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, const KCalCore::RecurrenceRule * );
+    friend KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, const KCalCore::RecurrenceRule * );
 };
 
+/**
+ * RecurrenceRule serializer and deserializer.
+ * @since 4.12
+ */
+KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, const KCalCore::RecurrenceRule * );
+KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, const KCalCore::RecurrenceRule * );
+
+/**
+ * RecurrenceRule::WDayPos serializer and deserializer.
+ * @since 4.12
+ */
+KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, const KCalCore::RecurrenceRule::WDayPos & );
+KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, KCalCore::RecurrenceRule::WDayPos &  );
+
 }
 
 #endif
