@@ -26,11 +26,13 @@
 
 class AlarmTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testValidity();
     void testCompare();
     void testAssignment();
+    void testSerializer_data();
+    void testSerializer();
 };
 
 #endif
