@@ -25,9 +25,11 @@
 
 class AttachmentTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testValidity();
+    void testSerializer_data();
+    void testSerializer();
 };
 
 #endif
