@@ -26,10 +26,12 @@
 
 class DurationTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testValidity();
     void testCompare();
+    void testSerializer_data();
+    void testSerializer();
 };
 
 #endif
