@@ -26,8 +26,8 @@
 
 class EventTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testSetRoles_data();
     void testSetRoles();
     void testValidity();
@@ -35,6 +35,8 @@ private Q_SLOTS:
     void testClone();
     void testCopy();
     void testAssign();
+    void testSerializer_data();
+    void testSerializer();
     void testDurationDtEnd();
 };
 
