@@ -26,13 +26,15 @@
 
 class JournalTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testValidity();
     void testCompare();
     void testClone();
     void testRich();
     void testAssign();
+    void testSerializer_data();
+    void testSerializer();
 };
 
 #endif
