@@ -26,8 +26,8 @@
 
 class RecurTodoTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testAllDay();
     void testNonAllDay();
     void testIsAllDay();
@@ -36,6 +36,9 @@ private Q_SLOTS:
     void testRecurrenceBasedOnDue();
     void testRecurrenceStart();
     void testHasDueDate();
+
+    void testRecurTodo_data();
+    void testRecurTodo();
 };
 
 #endif
