@@ -26,14 +26,17 @@
 
 class TodoTest : public QObject
 {
-    Q_OBJECT
-private Q_SLOTS:
+  Q_OBJECT
+  private Q_SLOTS:
     void testValidity();
     void testCompare();
     void testClone();
     void testAssign();
     void testSetCompleted();
     void testStatus();
+    void testSerializer_data();
+    void testSerializer();
+    void testRoles();
 };
 
 #endif
