@@ -21,7 +21,8 @@
 #include "query.h"
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
+#include <kurl.h>
 
 #include <QtCore/QDateTime>
 #include <QtCore/QVariant>
